@@ -11,7 +11,7 @@ use base qw(DynaLoader);
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '3.305';
+$VERSION = '3.314';
 
 ######################################################################
 #### Configuration Section
@@ -19,7 +19,7 @@ $VERSION = '3.305';
 bootstrap Verilog::Preproc;
 
 #In Preproc.xs:
-# sub _new (class, keepcmt, linedir, pedantic)
+# sub _new (class, keepcmt, linedir, pedantic, synthesis)
 # sub _open (class)
 # sub getall (class)
 # sub getline (class)
@@ -37,6 +37,7 @@ sub new {
 		keep_whitespace=>1,
 		line_directives=>1,
 		pedantic=>0,
+		synthesis=>0,
 		options=>Verilog::Getopt->new(),	# If the user didn't give one, still work!
 		#include_open_nonfatal=>0,
 		@_};
@@ -49,7 +50,11 @@ sub new {
 		$self->{keep_whitespace},
 		$self->{line_directives},
 		$self->{pedantic},
+		$self->{synthesis},
 		);
+    if ($self->{synthesis}) {
+	$self->define('SYNTHESIS',1);
+    }
     #use Data::Dumper; print Dumper($self);
     return $self;
 }
@@ -286,8 +291,8 @@ With keep_comments set to zero, strip all comments.  When set to one (the
 default), insert comments in output streams.  When set to 'sub', call the
 comment() function so that meta-comments can be processed outside of the
 output stream.  Note that some programs use meta-comments to embed useful
-information (synthesis and lint), so use this with caution if feeding to
-tools other than your own.  Defaults to 1.
+information (synthesis and lint), so strip with caution if feeding to tools
+other than your own.  Defaults to 1.
 
 =item keep_whitespace=>0
 
@@ -314,6 +319,14 @@ were added to the 1800-2009 standard.  It remains to disable `error and may
 disable other future features that are not specified in the language
 standard. Defaults false.
 
+=item synthesis=>1
+
+With synthesis set, define SYNTHESIS, and ignore text bewteen "ambit",
+"pragma", "synopsys" or "synthesis" translate_off and translate_on meta
+comments.  Note using metacomments is discouraged as they have led to
+silicon bugs (versus ifdef SYNTHESIS); see
+L<http://www.veripool.org/papers/TenIPEdits_SNUGBos07_paper.pdf>.
+
 =back
 
 =head1 CALLBACKS
@@ -409,7 +422,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2010 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2012 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
